import click
import os

from meerkat import email as send_email, ping as send_ping
from meerkat.api import get_user_token

@click.group()
def meerkat():
    pass

@meerkat.command()
def ping():
    send_ping()

@meerkat.command()
@click.argument('message', type=str)
def email(message):
    result = send_email(message=message)
    click.echo(f'{result}')

@meerkat.command()
def login():
    email = click.prompt("Enter Email")
    password = click.prompt("Enter Password", hide_input=True)
    token = get_user_token(email, password)

    if not token:
        click.echo("Invalid email or password.")
        return

    #save token to user HOME and set OS env
    with open(os.path.expanduser("~") + "/.meerkat", "w") as file:
        file.write(token)
    os.environ["MEERKAT_TOKEN"] = token

    click.echo(f"\nMeerkat initialized successfully.")

if __name__ == "__main__":
    meerkat()


import requests
import json

MEERKAT_BASE_URL = "http://127.0.0.1:5000/"

def send_meerkat_notification(notification_type: str, token: str, message: str):
    response = requests.post(MEERKAT_BASE_URL + "api/notification/send", json={
        "method": notification_type,
        "token": token,
        "message": message
    })
    print(response)

def get_user_token(email, password):
    response = requests.post(MEERKAT_BASE_URL + "api/user/token", json={
        "email": email,
        "password": password
    })
    if response.status_code == 200:
        return json.loads(response.text).get("token")
    else:
        return None


import os
import time
import platform
import pkg_resources
from IPython.core.magic import Magics, magics_class, line_magic
from IPython import get_ipython

from meerkat.api import send_meerkat_notification, get_user_token

module_runtime = int(time.time()*1000)

if not os.environ.get("MEERKAT_TOKEN"):
    try:
        with open(os.path.expanduser("~") + "/.meerkat") as file:
            os.environ["MEERKAT_TOKEN"] = file.read()
    except Exception as e:
        pass

def _play_sound(file_name: str):
    system = platform.system()
    if system == 'Darwin':  # macOS
        os.system(f'afplay {file_name}')
    elif system == 'Linux':
        os.system(f'aplay {file_name}')
    elif system == 'Windows':
        os.system(f'powershell -c "(New-Object Media.SoundPlayer \'{file_name}\').PlaySync();"')
    else:
        print('Unsupported operating system.')

#
# User Management Functions
#
def login(email: str, password: str) -> bool:
    token = get_user_token(email, password)

    if not token:
        print("Invalid Meerkat Token!")
        return False

    os.environ["MEERKAT_TOKEN"] = token
    return True

#
# Notification Functions
#
def ping():
    sound_path = pkg_resources.resource_filename('meerkat', 'ping_sounds/default_ping.mp3')
    _play_sound(sound_path)

def email(token=None, message=""):
    if token == None:
        token = os.environ.get("MEERKAT_TOKEN")

    if not token:
        print("No Meerkat token found in the environment")
        return
    
    return send_meerkat_notification("email", token, message)

#
# iPython Extension
#

@magics_class
class MeerkatMagics(Magics):
    @line_magic
    def ping(self, line):
        sound_path = pkg_resources.resource_filename('meerkat', 'ping_sounds/default_ping.mp3')
        _play_sound(sound_path)

    @line_magic
    def email(self, line):
        email(line)

    @line_magic
    def sms(self, line):
        #TODO: send_sms(line)
        pass

try:
    # Register the magics with the notebook
    ip = get_ipython()
    ip.register_magics(MeerkatMagics)
except:
    # not in a notebook
    pass


from setuptools import setup, find_packages

setup(
    name='meerkatio',
    version='1.8',
    packages=find_packages(),
    package_data={'meerkat': ['ping_sounds/*.mp3']},
    include_package_data=True,
    install_requires=[
        "requests",
        "click",
        "ipython"
    ],
    entry_points='''
        [console_scripts]
        meerkat=meerkat.cli:meerkat
    ''',
    author="MeerkatIO",
    description="Simple notification tool for multi-tasking developers",
    long_description=open("documentation.md").read(),
    long_description_content_type="text/markdown",
    license=open("LICENSE").read()
    # Add other metadata such as author, author_email, description, etc.
)
